@@ -1,11 +1,12 @@
-__version__ = '0.2.0'
+__version__ = '0.2.1'
 
-from .base import XyAdapter, XyData
+from .xyadapter import XyAdapter, XyAdapterBase, XyData
 
 __all__ = [
     "compose",
     "preprocessing",
     # Non-modules:
     "XyAdapter",
+    "XyAdapterBase",
     "XyData",
 ]
